Class: MG::Animate

Inherits:
Action show all
Defined in:
doc/API_reference.rb

Constructors collapse

Methods inherited from Action

#clone, #done?, #reverse

Constructor Details

#initialize(frame_names, delay, loops = 1) ⇒ Animate

Creates an animation action where the sprite display frame will be changed to the given frames in frame_names based on the given delay and repeated loops times.



339
# File 'doc/API_reference.rb', line 339

def initialize(frame_names, delay, loops=1); end