Class: MG::JumpBy

Inherits:
Action show all
Defined in:
doc/API_reference.rb

Constructors collapse

Methods inherited from Action

#clone, #done?, #reverse

Constructor Details

#initialize(delta_location, height, jumps, interval) ⇒ JumpBy

Creates an action that will jump the receiver to a new location determined by the sum of the current location and the given delta_location object.

Parameters:

  • a point that will be added to the receiver's current location during jumping.

  • the height of the jump

  • the number of jumps

  • the animation interval.



67
# File 'doc/API_reference.rb', line 67

def initialize(delta_location, height, jumps, interval); end