Class: MG::MoveBy

Inherits:
Action show all
Defined in:
doc/API_reference.rb

Constructors collapse

Methods inherited from Action

#clone, #done?, #reverse

Constructor Details

#initialize(delta_location, interval) ⇒ MoveBy

Creates an action that will move the position of the receiver to a new location determined by the sum of the current location and the given delta_location object.



39
# File 'doc/API_reference.rb', line 39

def initialize(delta_location, interval); end