Class: MG::Speed

Inherits:
Action show all
Defined in:
doc/API_reference.rb

Constructors collapse

Methods inherited from Action

#clone, #done?, #reverse

Constructor Details

#initialize(target_action, speed) ⇒ Speed

Changes the speed of an action, making it take longer (speed>1) or less (speed<1) time. Useful to simulate ‘slow motion’ or ‘fast forward’ effect. ** This action can’t be Sequenceable because it is not an IntervalAction.



294
# File 'doc/API_reference.rb', line 294

def initialize(target_action, speed); end